import { fetchAllUsers } from "@/lib/actions";
import { sha256sum } from "@/lib/util";
import { Avatar, Button, Flex, Heading, Table, Text } from "@radix-ui/themes";

export default async function Users() {
  const data = await fetchAllUsers();

  return (
    <>
      <Heading className="pb-4">Users</Heading>

      <Flex direction='column' className="flex-1">
        <Table.Root className="w-full" variant="surface">
          <Table.Header>
            <Table.Row>
              <Table.ColumnHeaderCell justify='start'>Email</Table.ColumnHeaderCell>
              <Table.ColumnHeaderCell justify='end'>Actions</Table.ColumnHeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {data.map((email) => (
              <Table.Row key={email}>
                <Table.Cell justify='start'>
                  <Flex direction='row' gap='4' align='center'>
                    <Avatar
                      size="2"
                      src={`https://gravatar.com/avatar/${sha256sum(email)}?d=monsterid`}
                      radius='full'
                      fallback={email.slice(0, 1) || "@"}
                    />
                    <Text size='2'>{email}</Text>
                  </Flex>
                </Table.Cell>
                <Table.Cell justify='end'>
                  <Button variant="soft">Manage</Button>
                </Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table.Root>
      </Flex>
    </>
  );
}