import type { Metadata } from 'next';
import ThemeWrapper from '@/lib/components/ThemeWrapper';
import './globals.css';
import AuthWrapper from '@/lib/components/AuthWrapper';
import { getServerSession } from 'next-auth';
import NavigationWrapper from '@/lib/components/NavigationWrapper';
import { ThemePanel } from '@radix-ui/themes';
import BackgroundImage from '@/lib/components/ui/BackgroundImage';

export const metadata: Metadata = {
  title: 'Maddy Admin',
  description: 'Maddy mail server configuration panel',
};

export default async function RootLayout({
  children,
}: {
  children: React.ReactNode
}) {
  return (
    <html lang="en">
      <body className={`p-4`}>
        <ThemeWrapper>
          <BackgroundImage />
          <AuthWrapper session={await getServerSession()}>
            <NavigationWrapper>
              {children}
            </NavigationWrapper>
          </AuthWrapper>
        </ThemeWrapper>
      </body>
    </html>
  );
}
